==> eam-wshub-proxyclient-11.4-11-sources.jar: net/datastream/schemas/mp_results/mp7038_001/MP7038_AddEmployee_001_Result.java <==

package net.datastream.schemas.mp_results.mp7038_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.Employee_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ResultData">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEEID"/>
 *                 &lt;/sequence>
 *                 &lt;attribute name="multiorg" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP7038_AddEmployee_001_Result")
public class MP7038_AddEmployee_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected MP7038_AddEmployee_001_Result.ResultData resultData;

    /**
     * Obtient la valeur de la propriété resultData.
     * 
     * @return
     *     possible object is
     *     {@link MP7038_AddEmployee_001_Result.ResultData }
     *     
     */
    public MP7038_AddEmployee_001_Result.ResultData getResultData() {
        return resultData;
    }

    /**
     * Définit la valeur de la propriété resultData.
     * 
     * @param value
     *     allowed object is
     *     {@link MP7038_AddEmployee_001_Result.ResultData }
     *     
     */
    public void setResultData(MP7038_AddEmployee_001_Result.ResultData value) {
        this.resultData = value;
    }


    /**
     * <p>Classe Java pour anonymous complex type.
     * 
     * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEEID"/>
     *       &lt;/sequence>
     *       &lt;attribute name="multiorg" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "employeeid"
    })
    public static class ResultData {

        @XmlElement(name = "EMPLOYEEID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
        protected Employee_Type employeeid;
        @XmlAttribute(name = "multiorg")
        protected String multiorg;

        /**
         * Obtient la valeur de la propriété employeeid.
         * 
         * @return
         *     possible object is
         *     {@link Employee_Type }
         *     
         */
        public Employee_Type getEMPLOYEEID() {
            return employeeid;
        }

        /**
         * Définit la valeur de la propriété employeeid.
         * 
         * @param value
         *     allowed object is
         *     {@link Employee_Type }
         *     
         */
        public void setEMPLOYEEID(Employee_Type value) {
            this.employeeid = value;
        }

        /**
         * Obtient la valeur de la propriété multiorg.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getMultiorg() {
            if (multiorg == null) {
                return "false";
            } else {
                return multiorg;
            }
        }

        /**
         * Définit la valeur de la propriété multiorg.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setMultiorg(String value) {
            this.multiorg = value;
        }

    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_results/mp7038_001/MP7038_AddEmployee_001_Result.java <==

package net.datastream.schemas.mp_results.mp7038_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.Employee_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ResultData">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEEID"/>
 *                 &lt;/sequence>
 *                 &lt;attribute name="multiorg" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP7038_AddEmployee_001_Result")
public class MP7038_AddEmployee_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected MP7038_AddEmployee_001_Result.ResultData resultData;

    /**
     * Gets the value of the resultData property.
     * 
     * @return
     *     possible object is
     *     {@link MP7038_AddEmployee_001_Result.ResultData }
     *     
     */
    public MP7038_AddEmployee_001_Result.ResultData getResultData() {
        return resultData;
    }

    /**
     * Sets the value of the resultData property.
     * 
     * @param value
     *     allowed object is
     *     {@link MP7038_AddEmployee_001_Result.ResultData }
     *     
     */
    public void setResultData(MP7038_AddEmployee_001_Result.ResultData value) {
        this.resultData = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEEID"/>
     *       &lt;/sequence>
     *       &lt;attribute name="multiorg" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "employeeid"
    })
    public static class ResultData {

        @XmlElement(name = "EMPLOYEEID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
        protected Employee_Type employeeid;
        @XmlAttribute(name = "multiorg")
        protected String multiorg;

        /**
         * Gets the value of the employeeid property.
         * 
         * @return
         *     possible object is
         *     {@link Employee_Type }
         *     
         */
        public Employee_Type getEMPLOYEEID() {
            return employeeid;
        }

        /**
         * Sets the value of the employeeid property.
         * 
         * @param value
         *     allowed object is
         *     {@link Employee_Type }
         *     
         */
        public void setEMPLOYEEID(Employee_Type value) {
            this.employeeid = value;
        }

        /**
         * Gets the value of the multiorg property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getMultiorg() {
            if (multiorg == null) {
                return "false";
            } else {
                return multiorg;
            }
        }

        /**
         * Sets the value of the multiorg property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setMultiorg(String value) {
            this.multiorg = value;
        }

    }

}
